diff --git a/src/web/Manager.mjs b/src/web/Manager.mjs
index 1be83fbc..b1720b66 100755
--- a/src/web/Manager.mjs
+++ b/src/web/Manager.mjs
@@ -141,6 +141,7 @@ class Manager {
document.getElementById("load-button").addEventListener("click", this.controls.loadButtonClick.bind(this.controls));
document.getElementById("support").addEventListener("click", this.controls.supportButtonClick.bind(this.controls));
this.addMultiEventListeners("#save-texts textarea", "keyup paste", this.controls.saveTextChange, this.controls);
+ this.addDynamicListener(".btn-maximise", "click", this.controls.handlePaneMaximising, this.controls);
// Operations
this.addMultiEventListener("#search", "keyup paste search click", this.ops.searchOperations, this.ops);
@@ -199,7 +200,7 @@ class Manager {
document.getElementById("save-all-to-file").addEventListener("click", this.output.saveAllClick.bind(this.output));
document.getElementById("copy-output").addEventListener("click", this.output.copyClick.bind(this.output));
document.getElementById("switch").addEventListener("click", this.output.switchClick.bind(this.output));
- document.getElementById("maximise-output").addEventListener("click", this.output.maximiseOutputClick.bind(this.output));
+ // document.getElementById("maximise-output").addEventListener("click", this.output.maximiseOutputClick.bind(this.output));
document.getElementById("magic").addEventListener("click", this.output.magicClick.bind(this.output));
this.addDynamicListener(".extract-file,.extract-file i", "click", this.output.extractFileClick, this.output);
this.addDynamicListener("#output-tabs-wrapper #output-tabs li .output-tab-content", "click", this.output.changeTabClick, this.output);
diff --git a/src/web/TODO.md b/src/web/TODO.md
index d2022927..bcfa2019 100644
--- a/src/web/TODO.md
+++ b/src/web/TODO.md
@@ -4,13 +4,13 @@
---
#### Mobile UI ( on real device ):
-- How to add operations to favourites since drag and drop is now disabled on mobile ( maybe a star icon...? )
-- Recipe list on mobile panel is too small to comfortably scroll and change order of recipes
-
- test *thoroughly* with keyboard popping up because that messes with view-heights on mobile probably and might make it a very frustrating experience
- test drag and drop etc. Regular mobile events / UX
- view-heights not correct due to variable taskbar on mobile devices
+- loading gears on mobile ( some ingredient labels 'shine through' and the cancel button isnt visible )
+- need long press checks on mobile to add favourites and switch ingredient order
+
### Desktop UI:
### General UI:
- fix up key / tab events so UI can be navigated comfortably with keys ( inc. visual focus feedback ). Probably a lot of work though
diff --git a/src/web/html/index.html b/src/web/html/index.html
index 947ea79f..eab663d1 100755
--- a/src/web/html/index.html
+++ b/src/web/html/index.html
@@ -198,7 +198,7 @@
data-help-title="Operations list"
data-help="
The Operations list contains all the operations in CyberChef arranged into categories. Some operations may be present in multiple categories. You can search for operations using the search box.
To use an operation, either double click it, or drag it into the Recipe pane. You will then be able to configure its arguments (or 'Ingredients' in CyberChef terminology).
diff --git a/src/web/App.mjs b/src/web/App.mjs
index c5202be8..2710b045 100755
--- a/src/web/App.mjs
+++ b/src/web/App.mjs
@@ -315,7 +315,7 @@ class App {
this.columnSplitter = Split(["#operations", "#recipe", "#IO"], {
sizes: [20, 30, 50],
- minSize: minimise ? [0, 0, 0] : [240, 310, 450],
+ minSize: minimise ? [0, 0, 0] : [20, 30, 50],
gutterSize: 4,
expandToMin: true,
onDrag: debounce(function() {
@@ -326,7 +326,7 @@ class App {
this.ioSplitter = Split(["#input", "#output"], {
direction: "vertical",
gutterSize: 4,
- minSize: minimise ? [0, 0] : [100, 100]
+ minSize: minimise ? [0, 0] : [50, 50]
});
this.adjustComponentSizes();
@@ -341,7 +341,6 @@ class App {
this.columnSplitter = Split(["#operations", "#recipe", "#IO"], {
sizes: [100, 100, 100],
- minSize: [0, 0, 0],
gutterSize: 0,
expandToMin: true,
});
@@ -649,7 +648,7 @@ class App {
/**
- * Resets the splitter positions to default.
+ * Resets the splitter positions to default for desktop UI.
*/
resetLayout() {
this.columnSplitter.setSizes([20, 30, 50]);
@@ -657,6 +656,7 @@ class App {
this.adjustComponentSizes();
}
+
/**
* Adjust components to fit their containers.
*/
@@ -857,13 +857,13 @@ class App {
/**
* Set element visibility
*
* @param {HTMLElement} elm
* @param {boolean} isVisible
*
*/
- setVisibility( elm, isVisible ){
+ updateVisibility( elm, isVisible ){
if ( isVisible ) {
if ( elm.classList.contains("hidden")) {
elm.classList.remove("hidden");
@@ -876,10 +876,6 @@ class App {
}
/**
- * A collection of function calls that need to fire on
- * window resizing when the window inner width >= the
- * breakpoint
- *
* @param {boolean} minimise
*/
setDesktopUI(minimise){
@@ -893,11 +889,6 @@ class App {
this.manager.recipe.clearAllSelectedClasses();
}
- /**
- * A collection of function calls that need to fire on
- * window resizing when the window inner width < the
- * breakpoint
- */
setMobileUI(){
this.setMobileLayout();
// repopulate to disable popovers and drag events
@@ -857,13 +857,13 @@ class App {
/**
- * Set element visibility
+ * Update element visibility
*
* @param {HTMLElement} elm